==> ugrp-0.2.1.gem: app/controllers/ugrp/users/sessions_controller.rb <==
# frozen_string_literal: true

require_dependency 'ugrp/ugrp_controller'
require 'devise/version'

# Extend ::Devise::SessionsController
module Ugrp
  module Users
    class SessionsController < ::Devise::SessionsController
      include Recaptcha::Adapters::ControllerMethods

      # # before_action :configure_sign_in_params, only: [:create]
      # prepend_before_action :check_captcha, only: [:create] #, unless: ::Recaptcha.configuration.site_key.nil? # Change this to be any actions you want to protect.

      # GET /resource/sign_in
      # def new
      #   super
      # end

      # POST /resource/sign_in
      # def create
      #   super
      # end

      def create
        recaptcha_valid = true || ::Recaptcha.configuration.site_key.nil? || verify_recaptcha(model: @user, action: 'session')
        if recaptcha_valid
          super
        else
          flash.now[:error] = 'Recaptcha Human Check Failed'
          redirect_to new_user_session_path
        end
      end

      # DELETE /resource/sign_out
      # def destroy
      #   super
      # end

      protected

      # If you have extra params to permit, append them to the sanitizer.
      # def configure_sign_in_params
      #   # devise_parameter_sanitizer.for(:sign_in).push(:login, :username, :name, :email)
      #   devise_parameter_sanitizer.permit(:sign_in, keys: [:login, :username, :name, :email])
      # end

      def check_captcha
        return if verify_recaptcha

        self.resource = resource_class.new sign_in_params
        respond_with_navigational(resource) { render :new }
      end
    end
  end
end

==> ugrp-0.2.2.gem: app/controllers/ugrp/users/sessions_controller.rb <==
# frozen_string_literal: true

require_dependency 'ugrp/ugrp_controller'
require 'devise/version'

# Extend Devise::SessionsController
module Ugrp
  module Users
    class SessionsController < Devise::SessionsController
      include Recaptcha::Adapters::ControllerMethods

      # # before_action :configure_sign_in_params, only: [:create]
      # prepend_before_action :check_captcha, only: [:create] #, unless: Recaptcha.configuration.site_key.nil? # Change this to be any actions you want to protect.

      # GET /resource/sign_in
      # def new
      #   super
      # end

      # POST /resource/sign_in
      # def create
      #   super
      # end

      def create
        recaptcha_valid = true || Recaptcha.configuration.site_key.nil? || verify_recaptcha(model: @user, action: 'session')
        if recaptcha_valid
          super
        else
          flash.now[:error] = 'Recaptcha Human Check Failed'
          redirect_to new_user_session_path
        end
      end

      # DELETE /resource/sign_out
      # def destroy
      #   super
      # end

      protected

      # If you have extra params to permit, append them to the sanitizer.
      # def configure_sign_in_params
      #   # devise_parameter_sanitizer.for(:sign_in).push(:login, :username, :name, :email)
      #   devise_parameter_sanitizer.permit(:sign_in, keys: [:login, :username, :name, :email])
      # end

      def check_captcha
        return if verify_recaptcha

        self.resource = resource_class.new sign_in_params
        respond_with_navigational(resource) { render :new }
      end
    end
  end
end
